@@ -1,6 +1,9 @@
 /***************************************************************************
     copyright            : (C) 2004 by Scott Wheeler
     email                : wheeler@kde.org
+
+    copyright            : (C) 2009 by Michael Pyne
+    email                : michael.pyne@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -12,16 +15,31 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <kurl.h>
+#include "playlistcollection.h"
 
-#include <config.h>
-#include <qobjectlist.h>
+#include <kurl.h>
+#include <kicon.h>
+#include <kiconloader.h>
+#include <kapplication.h>
+#include <kinputdialog.h>
+#include <kmessagebox.h>
+#include <kfiledialog.h>
+#include <kaction.h>
+#include <kactioncollection.h>
+#include <ktoggleaction.h>
+#include <kactionmenu.h>
+#include <kconfiggroup.h>
+
+#include <config-juk.h>
+
+#include <QObject>
+#include <QPixmap>
+#include <QStackedWidget>
 
 #include <sys/types.h>
 #include <dirent.h>
 
 #include "collectionlist.h"
-#include "playlistcollection.h"
 #include "actioncollection.h"
 #include "advancedsearchdialog.h"
 #include "coverinfo.h"
@@ -33,18 +51,10 @@
 #include "mediafiles.h"
 #include "playermanager.h"
 #include "tracksequencemanager.h"
+#include "juk.h"
 
-#include <kiconloader.h>
-#include <kactionclasses.h>
-#include <kapplication.h>
-#include <kinputdialog.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
-
-#include <qwidgetstack.h>
-#include <qhbox.h>
-
-#define widget (kapp->mainWidget())
+//Laurent: readd it
+//#include "collectionadaptor.h"
 
 using namespace ActionCollection;
 
@@ -58,7 +68,7 @@ PlaylistCollection *PlaylistCollection::m_instance = 0;
 // public methods
 ////////////////////////////////////////////////////////////////////////////////
 
-PlaylistCollection::PlaylistCollection(QWidgetStack *playlistStack) :
+PlaylistCollection::PlaylistCollection(QStackedWidget *playlistStack) :
     m_playlistStack(playlistStack),
     m_historyPlaylist(0),
     m_upcomingPlaylist(0),
@@ -71,10 +81,11 @@ PlaylistCollection::PlaylistCollection(QWidgetStack *playlistStack) :
     m_belowDistraction(0),
     m_distraction(0)
 {
+    //new CollectionAdaptor( this );
+    //QDBus::sessionBus().registerObject("/Collection",this );
     m_instance = this;
 
     m_actionHandler = new ActionHandler(this);
-    PlayerManager::instance()->setPlaylistInterface(this);
 
     // KDirLister's auto error handling seems to crash JuK during startup in
     // readConfig().
@@ -87,7 +98,6 @@ PlaylistCollection::~PlaylistCollection()
 {
     saveConfig();
     delete m_actionHandler;
-    PlayerManager::instance()->setPlaylistInterface(0);
     Playlist::setShuttingDown();
 }
 
@@ -155,14 +165,12 @@ QStringList PlaylistCollection::playlists() const
 {
     QStringList l;
 
-    QObjectList *childList = m_playlistStack->queryList("Playlist");
-    QObject *obj;
-    for(obj = childList->first(); obj; obj = childList->next()) {
-        Playlist *p = static_cast<Playlist *>(obj);
+    //(or qFindChildren() if you need MSVC 6 compatibility)
+    const QList<Playlist *> childList = m_playlistStack->findChildren<Playlist *>("Playlist");
+    foreach(Playlist *p, childList) {
         l.append(p->name());
     }
 
-    delete childList;
     return l;
 }
 
@@ -177,7 +185,7 @@ void PlaylistCollection::createDynamicPlaylist(const PlaylistList &playlists)
         m_dynamicPlaylist->setPlaylists(playlists);
     else
         m_dynamicPlaylist =
-            new DynamicPlaylist(playlists, this, i18n("Dynamic List"), "midi", false, true);
+            new DynamicPlaylist(playlists, this, i18n("Dynamic List"), "audio-midi", false, true);
 
     PlaylistCollection::raise(m_dynamicPlaylist);
 }
@@ -223,7 +231,7 @@ void PlaylistCollection::showMore(const QString &artist, const QString &album)
     // so cache the value we want it to have now.
     Playlist *belowShowMore = visiblePlaylist();
 
-    PlaylistCollection::setupPlaylist(m_showMorePlaylist, QString::null);
+    PlaylistCollection::setupPlaylist(m_showMorePlaylist, QString());
     PlaylistCollection::raise(m_showMorePlaylist);
 
     m_belowShowMorePlaylist = belowShowMore;
@@ -252,12 +260,12 @@ void PlaylistCollection::removeTrack(const QString &playlist, const QStringList
 
 QString PlaylistCollection::playlist() const
 {
-    return visiblePlaylist() ? visiblePlaylist()->name() : QString::null;
+    return visiblePlaylist() ? visiblePlaylist()->name() : QString();
 }
 
 QString PlaylistCollection::playingPlaylist() const
 {
-    return currentPlaylist() && m_playing ? currentPlaylist()->name() : QString::null;
+    return currentPlaylist() && m_playing ? currentPlaylist()->name() : QString();
 }
 
 void PlaylistCollection::setPlaylist(const QString &playlist)
@@ -281,12 +289,12 @@ QString PlaylistCollection::trackProperty(const QString &file, const QString &pr
     CollectionList *l = CollectionList::instance();
     CollectionListItem *item = l->lookup(file);
 
-    return item ? item->file().property(property) : QString::null;
+    return item ? item->file().property(property) : QString();
 }
 
 QPixmap PlaylistCollection::trackCover(const QString &file, const QString &size) const
 {
-    if(size.lower() != "small" && size.lower() != "large")
+    if(size.toLower() != "small" && size.toLower() != "large")
         return QPixmap();
 
     CollectionList *l = CollectionList::instance();
@@ -295,7 +303,7 @@ QPixmap PlaylistCollection::trackCover(const QString &file, const QString &size)
     if(!item)
         return QPixmap();
 
-    if(size.lower() == "small")
+    if(size.toLower() == "small")
         return item->file().coverInfo()->pixmap(CoverInfo::Thumbnail);
     else
         return item->file().coverInfo()->pixmap(CoverInfo::FullSize);
@@ -306,22 +314,22 @@ void PlaylistCollection::open(const QStringList &l)
     QStringList files = l;
 
     if(files.isEmpty())
-        files = MediaFiles::openDialog(widget);
+        files = MediaFiles::openDialog(JuK::JuKInstance());
 
     if(files.isEmpty())
         return;
 
     bool justPlaylists = true;
 
-    for(QStringList::ConstIterator it = l.begin(); it != l.end() && justPlaylists; ++it)
+    for(QStringList::ConstIterator it = files.constBegin(); it != files.constEnd() && justPlaylists; ++it)
         justPlaylists = !MediaFiles::isPlaylistFile(*it);
 
     if(visiblePlaylist() == CollectionList::instance() || justPlaylists ||
        KMessageBox::questionYesNo(
-           widget,
+           JuK::JuKInstance(),
            i18n("Do you want to add these items to the current list or to the collection list?"),
-           QString::null,
-           KGuiItem(i18n("Current")),
+           QString(),
+           KGuiItem(i18nc("current playlist", "Current")),
            KGuiItem(i18n("Collection"))) == KMessageBox::No)
     {
         CollectionList::instance()->addFiles(files);
@@ -342,8 +350,7 @@ void PlaylistCollection::open(const QString &playlist, const QStringList &files)
 
 void PlaylistCollection::addFolder()
 {
-    kdDebug(65432) << k_funcinfo << endl;
-    DirectoryList l(m_folderList, m_importPlaylists, widget, "directoryList");
+    DirectoryList l(m_folderList, m_importPlaylists, JuK::JuKInstance());
     DirectoryList::Result result = l.exec();
 
     if(result.status == QDialog::Accepted) {
@@ -353,18 +360,14 @@ void PlaylistCollection::addFolder()
         const bool reload = m_importPlaylists != result.addPlaylists;
         m_importPlaylists = result.addPlaylists;
 
-        for(QStringList::Iterator it = result.addedDirs.begin();
-            it != result.addedDirs.end(); it++)
-        {
-            m_dirLister.openURL(*it, true);
-            m_folderList.append(*it);
+        foreach(const QString &dir, result.addedDirs) {
+            m_dirLister.openUrl(KUrl::fromPath(dir), KDirLister::Keep);
+            m_folderList.append(dir);
         }
 
-        for(QStringList::Iterator it = result.removedDirs.begin();
-            it !=  result.removedDirs.end(); it++)
-        {
-            m_dirLister.stop(*it);
-            m_folderList.remove(*it);
+        foreach(const QString &dir, result.removedDirs) {
+            m_dirLister.stop(KUrl::fromPath(dir));
+            m_folderList.removeAll(dir);
         }
 
         if(reload)
@@ -385,7 +388,7 @@ void PlaylistCollection::rename()
 
     m_playlistNames.remove(old);
 
-    if(name.isNull())
+    if(name.isEmpty())
         return;
 
     visiblePlaylist()->setName(name);
@@ -393,9 +396,11 @@ void PlaylistCollection::rename()
 
 void PlaylistCollection::duplicate()
 {
-    QString name = playlistNameDialog(i18n("Duplicate"), visiblePlaylist()->name());
-    if(name.isNull())
+    QString name = playlistNameDialog(i18nc("verb, copy the playlist", "Duplicate"),
+                                      visiblePlaylist()->name());
+    if(name.isEmpty())
         return;
+
     raise(new Playlist(this, visiblePlaylist()->items(), name));
 }
 
@@ -426,7 +431,7 @@ void PlaylistCollection::editSearch()
         return;
 
     AdvancedSearchDialog::Result r =
-        AdvancedSearchDialog(p->name(), p->playlistSearch(), widget).exec();
+        AdvancedSearchDialog(p->name(), p->playlistSearch(), JuK::JuKInstance()).exec();
 
     if(r.result == AdvancedSearchDialog::Accepted) {
         p->setPlaylistSearch(r.search);
@@ -487,7 +492,7 @@ void PlaylistCollection::scanFolders()
 void PlaylistCollection::createPlaylist()
 {
     QString name = playlistNameDialog();
-    if(!name.isNull())
+    if(!name.isEmpty())
         raise(new Playlist(this, name));
 }
 
@@ -496,7 +501,7 @@ void PlaylistCollection::createSearchPlaylist()
     QString name = uniquePlaylistName(i18n("Search Playlist"));
 
     AdvancedSearchDialog::Result r =
-        AdvancedSearchDialog(name, PlaylistSearch(), widget).exec();
+        AdvancedSearchDialog(name, PlaylistSearch(), JuK::JuKInstance()).exec();
 
     if(r.result == AdvancedSearchDialog::Accepted)
         raise(new SearchPlaylist(this, r.search, r.playlistName));
@@ -509,10 +514,10 @@ void PlaylistCollection::createFolderPlaylist()
     if(folder.isEmpty())
         return;
 
-    QString name = uniquePlaylistName(folder.mid(folder.findRev('/') + 1));
+    QString name = uniquePlaylistName(folder.mid(folder.lastIndexOf('/') + 1));
     name = playlistNameDialog(i18n("Create Folder Playlist"), name);
 
-    if(!name.isNull())
+    if(!name.isEmpty())
         raise(new FolderPlaylist(this, folder, name));
 }
 
@@ -550,7 +555,7 @@ void PlaylistCollection::setHistoryPlaylistEnabled(bool enable)
         action<KToggleAction>("showHistory")->setChecked(true);
         m_historyPlaylist = new HistoryPlaylist(this);
         m_historyPlaylist->setName(i18n("History"));
-        setupPlaylist(m_historyPlaylist, "history");
+        setupPlaylist(m_historyPlaylist, "view-history");
     }
     else {
         delete m_historyPlaylist;
@@ -573,11 +578,11 @@ void PlaylistCollection::setUpcomingPlaylistEnabled(bool enable)
         if(!m_upcomingPlaylist)
             m_upcomingPlaylist = new UpcomingPlaylist(this);
 
-        setupPlaylist(m_upcomingPlaylist, "today");
+        setupPlaylist(m_upcomingPlaylist, "go-jump-today");
     }
     else {
         action<KToggleAction>("showUpcoming")->setChecked(false);
-        bool raiseCollection = m_playlistStack->visibleWidget() == m_upcomingPlaylist;
+        bool raiseCollection = visiblePlaylist() == m_upcomingPlaylist;
         delete m_upcomingPlaylist;
         m_upcomingPlaylist = 0;
 
@@ -609,7 +614,7 @@ Playlist *PlaylistCollection::currentPlaylist() const
 
 Playlist *PlaylistCollection::visiblePlaylist() const
 {
-    return static_cast<Playlist *>(m_playlistStack->visibleWidget());
+    return qobject_cast<Playlist *>(m_playlistStack->currentWidget());
 }
 
 void PlaylistCollection::raise(Playlist *playlist)
@@ -622,7 +627,7 @@ void PlaylistCollection::raise(Playlist *playlist)
     TrackSequenceManager::instance()->setCurrentPlaylist(playlist);
     playlist->applySharedSettings();
     playlist->setSearchEnabled(m_searchEnabled);
-    m_playlistStack->raiseWidget(playlist);
+    m_playlistStack->setCurrentWidget(playlist);
     clearShowMore(false);
     dataChanged();
 }
@@ -635,11 +640,11 @@ void PlaylistCollection::raiseDistraction()
     m_belowDistraction = currentPlaylist();
 
     if(!m_distraction) {
-        m_distraction = new QHBox(m_playlistStack);
+        m_distraction = new QWidget(m_playlistStack);
         m_playlistStack->addWidget(m_distraction);
     }
 
-    m_playlistStack->raiseWidget(m_distraction);
+    m_playlistStack->setCurrentWidget(m_distraction);
 }
 
 void PlaylistCollection::lowerDistraction()
@@ -648,7 +653,7 @@ void PlaylistCollection::lowerDistraction()
         return;
 
     if(m_belowDistraction)
-        m_playlistStack->raiseWidget(m_belowDistraction);
+        m_playlistStack->setCurrentWidget(m_belowDistraction);
 
     m_belowDistraction = 0;
 }
@@ -657,19 +662,20 @@ void PlaylistCollection::lowerDistraction()
 // protected methods
 ////////////////////////////////////////////////////////////////////////////////
 
-QWidgetStack *PlaylistCollection::playlistStack() const
+QStackedWidget *PlaylistCollection::playlistStack() const
 {
     return m_playlistStack;
 }
 
 void PlaylistCollection::setupPlaylist(Playlist *playlist, const QString &)
 {
-    if(!playlist->fileName().isNull())
+    if(!playlist->fileName().isEmpty())
         m_playlistFiles.insert(playlist->fileName());
 
-    if(!playlist->name().isNull())
+    if(!playlist->name().isEmpty())
         m_playlistNames.insert(playlist->name());
 
+    m_playlistStack->addWidget(playlist);
     QObject::connect(playlist, SIGNAL(selectionChanged()),
                      object(), SIGNAL(signalSelectedItemsChanged()));
 }
@@ -712,10 +718,10 @@ void PlaylistCollection::enableDirWatch(bool enable)
     if(enable) {
         QObject::connect(&m_dirLister, SIGNAL(newItems(const KFileItemList &)),
                 object(), SLOT(slotNewItems(const KFileItemList &)));
-        QObject::connect(&m_dirLister, SIGNAL(refreshItems(const KFileItemList &)),
-                collection, SLOT(slotRefreshItems(const KFileItemList &)));
-        QObject::connect(&m_dirLister, SIGNAL(deleteItem(KFileItem *)),
-                collection, SLOT(slotDeleteItem(KFileItem *)));
+        QObject::connect(&m_dirLister, SIGNAL(refreshItems(const QList<QPair<KFileItem, KFileItem> > &)),
+                collection, SLOT(slotRefreshItems(const QList<QPair<KFileItem, KFileItem> > &)));
+        QObject::connect(&m_dirLister, SIGNAL(deleteItem(const KFileItem &)),
+                collection, SLOT(slotDeleteItem(const KFileItem &)));
     }
 }
 
@@ -731,7 +737,7 @@ QString PlaylistCollection::playlistNameDialog(const QString &caption,
         forceUnique ? uniquePlaylistName(suggest) : suggest,
         &ok);
 
-    return ok ? uniquePlaylistName(name) : QString::null;
+    return ok ? uniquePlaylistName(name) : QString();
 }
 
 
@@ -779,25 +785,18 @@ void PlaylistCollection::removeFileFromDict(const QString &file)
 
 void PlaylistCollection::dirChanged(const QString &path)
 {
-    CollectionList::instance()->addFiles(path);
+    CollectionList::instance()->addFiles(QStringList(path));
 }
 
 Playlist *PlaylistCollection::playlistByName(const QString &name) const
 {
-    QObjectList *l = m_playlistStack->queryList("Playlist");
-    Playlist *list = 0;
-    QObject *obj;
-
-    for(obj = l->first(); obj; obj = l->next()) {
-        Playlist *p = static_cast<Playlist*>(obj);
-        if(p->name() == name) {
-            list = p;
-            break;
-        }
+    for(int i = 0; i < m_playlistStack->count(); ++i) {
+        Playlist *p = qobject_cast<Playlist *>(m_playlistStack->widget(i));
+        if(p && p->name() == name)
+            return p;
     }
 
-    delete l;
-    return list;
+    return 0;
 }
 
 void PlaylistCollection::newItems(const KFileItemList &list) const
@@ -813,19 +812,21 @@ void PlaylistCollection::readConfig()
 {
     KConfigGroup config(KGlobal::config(), "Playlists");
 
-    m_importPlaylists  = config.readBoolEntry("ImportPlaylists", true);
-    m_folderList       = config.readPathListEntry("DirectoryList");
+    m_importPlaylists  = config.readEntry("ImportPlaylists", true);
+    m_folderList       = config.readEntry("DirectoryList", QStringList());
 
-    for(QStringList::ConstIterator it = m_folderList.begin(); it != m_folderList.end(); ++it)
-        m_dirLister.openURL(*it, true);
+    foreach(const QString &folder, m_folderList)
+        m_dirLister.openUrl(folder, KDirLister::Keep);
 }
 
 void PlaylistCollection::saveConfig()
 {
     KConfigGroup config(KGlobal::config(), "Playlists");
     config.writeEntry("ImportPlaylists", m_importPlaylists);
-    config.writeEntry("showUpcoming", action<KToggleAction>("showUpcoming")->isChecked());
+    config.writeEntry("showUpcoming", action("showUpcoming")->isChecked());
     config.writePathEntry("DirectoryList", m_folderList);
+
+    config.sync();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -833,81 +834,81 @@ void PlaylistCollection::saveConfig()
 ////////////////////////////////////////////////////////////////////////////////
 
 PlaylistCollection::ActionHandler::ActionHandler(PlaylistCollection *collection) :
-    QObject(0, "ActionHandler"),
+    QObject(0),
     m_collection(collection)
 {
+    setObjectName("ActionHandler");
+
     KActionMenu *menu;
 
     // "New" menu
 
-    menu = new KActionMenu(i18n("&New"), "filenew", actions(), "file_new");
+    menu = new KActionMenu(KIcon("document-new"), i18nc("new playlist", "&New"), actions());
+    actions()->addAction("file_new", menu);
 
-    menu->insert(createAction(i18n("&Empty Playlist..."), SLOT(slotCreatePlaylist()),
-                              "newPlaylist", "window_new", "CTRL+n"));
-    menu->insert(createAction(i18n("&Search Playlist..."), SLOT(slotCreateSearchPlaylist()),
-                              "newSearchPlaylist", "find", "CTRL+f"));
-    menu->insert(createAction(i18n("Playlist From &Folder..."), SLOT(slotCreateFolderPlaylist()),
-                              "newDirectoryPlaylist", "fileopen", "CTRL+d"));
+    menu->addAction(createAction(i18n("&Empty Playlist..."), SLOT(slotCreatePlaylist()),
+                              "newPlaylist", "window-new", KShortcut(Qt::CTRL + Qt::Key_N)));
+    menu->addAction(createAction(i18n("&Search Playlist..."), SLOT(slotCreateSearchPlaylist()),
+                              "newSearchPlaylist", "edit-find", KShortcut(Qt::CTRL + Qt::Key_F)));
+    menu->addAction(createAction(i18n("Playlist From &Folder..."), SLOT(slotCreateFolderPlaylist()),
+                              "newDirectoryPlaylist", "document-open", KShortcut(Qt::CTRL + Qt::Key_D)));
 
     // Guess tag info menu
 
-#if HAVE_MUSICBRAINZ
-    menu = new KActionMenu(i18n("&Guess Tag Information"), QString::null, actions(), "guessTag");
-    menu->setIconSet(SmallIconSet("wizard"));
+#ifdef HAVE_TUNEPIMP
+    menu = new KActionMenu(i18n("&Guess Tag Information"), actions());
+    actions()->addAction("guessTag", menu);
 
-    menu->insert(createAction(i18n("From &File Name"), SLOT(slotGuessTagFromFile()),
-                              "guessTagFile", "fileimport", "CTRL+g"));
-    menu->insert(createAction(i18n("From &Internet"), SLOT(slotGuessTagFromInternet()),
-                              "guessTagInternet", "connect_established", "CTRL+i"));
+    /* menu->setIcon(SmallIcon("wizard")); */
+
+    menu->addAction(createAction(i18n("From &File Name"), SLOT(slotGuessTagFromFile()),
+                              "guessTagFile", "document-import", KShortcut(Qt::CTRL + Qt::Key_G)));
+    menu->addAction(createAction(i18n("From &Internet"), SLOT(slotGuessTagFromInternet()),
+                              "guessTagInternet", "network-server", KShortcut(Qt::CTRL + Qt::Key_I)));
 #else
     createAction(i18n("Guess Tag Information From &File Name"), SLOT(slotGuessTagFromFile()),
-                 "guessTag", "fileimport", "CTRL+f");
+                 "guessTag", "document-import", KShortcut(Qt::CTRL + Qt::Key_F));
 #endif
 
 
     createAction(i18n("Play First Track"),SLOT(slotPlayFirst()),     "playFirst");
-    createAction(i18n("Play Next Album"), SLOT(slotPlayNextAlbum()), "forwardAlbum", "next");
+    createAction(i18n("Play Next Album"), SLOT(slotPlayNextAlbum()), "forwardAlbum", "go-down-search");
 
-    createAction(i18n("Open..."),         SLOT(slotOpen()),         "file_open", "fileopen", "CTRL+o");
-    createAction(i18n("Add &Folder..."),  SLOT(slotAddFolder()),    "openDirectory", "fileopen");
-    createAction(i18n("&Rename..."),      SLOT(slotRename()),       "renamePlaylist", "lineedit");
-    createAction(i18n("D&uplicate..."),   SLOT(slotDuplicate()),    "duplicatePlaylist", "editcopy");
-    createAction(i18n("Save"),            SLOT(slotSave()),         "file_save", "filesave", "CTRL+s");
-    createAction(i18n("Save As..."),      SLOT(slotSaveAs()),       "file_save_as", "filesaveas");
-    createAction(i18n("R&emove"),         SLOT(slotRemove()),       "deleteItemPlaylist", "edittrash");
-    createAction(i18n("Reload"),          SLOT(slotReload()),       "reloadPlaylist", "reload");
-    createAction(i18n("Edit Search..."),  SLOT(slotEditSearch()),   "editSearch", "editclear");
+    KStandardAction::open(this, SLOT(slotOpen()), actions());
+    KStandardAction::save(this, SLOT(slotSave()), actions());
+    KStandardAction::saveAs(this, SLOT(slotSaveAs()), actions());
 
-    createAction(i18n("&Delete"),         SLOT(slotRemoveItems()),  "removeItem", "editdelete");
-    createAction(i18n("Refresh"),         SLOT(slotRefreshItems()), "refresh", "reload");
-    createAction(i18n("&Rename File"),    SLOT(slotRenameItems()),  "renameFile", "filesaveas", "CTRL+r");
+    createAction(i18n("Add &Folder..."),  SLOT(slotAddFolder()),    "openDirectory", "folder-new");
+    createAction(i18n("&Rename..."),      SLOT(slotRename()),       "renamePlaylist", "edit-rename");
+    createAction(i18nc("verb, copy the playlist", "D&uplicate..."),
+                 SLOT(slotDuplicate()),    "duplicatePlaylist", "edit-copy");
+    createAction(i18n("R&emove"),         SLOT(slotRemove()),       "deleteItemPlaylist", "user-trash");
+    createAction(i18n("Reload"),          SLOT(slotReload()),       "reloadPlaylist", "view-refresh");
+    createAction(i18n("Edit Search..."),  SLOT(slotEditSearch()),   "editSearch");
 
-    menu = new KActionMenu(i18n("Cover Manager"), QString::null, actions(), "coverManager");
-    menu->setIconSet(SmallIconSet("image"));
-    menu->insert(createAction(i18n("&View Cover"),
-        SLOT(slotViewCovers()), "viewCover", "viewmag"));
-    menu->insert(createAction(i18n("Get Cover From &File..."),
-        SLOT(slotAddLocalCover()), "addCover", "fileimport", "CTRL+SHIFT+f"));
+    createAction(i18n("&Delete"),         SLOT(slotRemoveItems()),  "removeItem", "edit-delete");
+    createAction(i18n("Refresh"),         SLOT(slotRefreshItems()), "refresh", "view-refresh");
+    createAction(i18n("&Rename File"),    SLOT(slotRenameItems()),  "renameFile", "document-save-as", KShortcut(Qt::CTRL + Qt::Key_R));
 
-    // Do not rename googleCover for backward compatibility
-    menu->insert(createAction(i18n("Get Cover From &Internet..."),
-        SLOT(slotAddInternetCover()), "googleCover", "connect_established", "CTRL+SHIFT+g"));
-    menu->insert(createAction(i18n("&Delete Cover"),
-        SLOT(slotRemoveCovers()), "removeCover", "editdelete"));
-    menu->insert(createAction(i18n("Show Cover &Manager"),
+    menu = new KActionMenu(i18n("Cover Manager"), actions());
+    actions()->addAction("coverManager", menu);
+    /* menu->setIcon(SmallIcon("image-x-generic")); */
+    menu->addAction(createAction(i18n("&View Cover"),
+        SLOT(slotViewCovers()), "viewCover", "document-preview"));
+    menu->addAction(createAction(i18n("Get Cover From &File..."),
+        SLOT(slotAddLocalCover()), "addCover", "document-import", KShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_F)));
+    menu->addAction(createAction(i18n("Get Cover From &Internet..."),
+        SLOT(slotAddInternetCover()), "webImageCover", "network-server", KShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_G)));
+    menu->addAction(createAction(i18n("&Delete Cover"),
+        SLOT(slotRemoveCovers()), "removeCover", "edit-delete"));
+    menu->addAction(createAction(i18n("Show Cover &Manager"),
         SLOT(slotShowCoverManager()), "showCoverManager"));
 
-    KToggleAction *historyAction =
-        new KToggleAction(i18n("Show &History"), "history",  0, actions(), "showHistory");
-    historyAction->setCheckedState(i18n("Hide &History"));
-
     KToggleAction *upcomingAction =
-        new KToggleAction(i18n("Show &Play Queue"), "today", 0, actions(), "showUpcoming");
-    upcomingAction->setCheckedState(i18n("Hide &Play Queue"));
+        new KToggleAction(KIcon("go-jump-today"), i18n("Show &Play Queue"), actions());
+    actions()->addAction("showUpcoming", upcomingAction);
 
-    connect(action<KToggleAction>("showHistory"), SIGNAL(toggled(bool)),
-            this, SLOT(slotSetHistoryPlaylistEnabled(bool)));
-    connect(action<KToggleAction>("showUpcoming"), SIGNAL(toggled(bool)),
+    connect(upcomingAction, SIGNAL(triggered(bool)),
             this, SLOT(slotSetUpcomingPlaylistEnabled(bool)));
 }
 
@@ -917,13 +918,17 @@ KAction *PlaylistCollection::ActionHandler::createAction(const QString &text,
                                                          const QString &icon,
                                                          const KShortcut &shortcut)
 {
+    KAction *action;
     if(icon.isNull())
-        return new KAction(text, shortcut, this, slot, actions(), name);
+        action = new KAction(text, actions());
     else
-        return new KAction(text, icon, shortcut, this, slot, actions(), name);
+        action = new KAction(KIcon(icon), text, actions());
+    actions()->addAction(name, action);
+    connect( action, SIGNAL(triggered(bool)), slot);
+    action->setShortcut(shortcut);
+    return action;
 }
 
-#undef widget
 #include "playlistcollection.moc"
 
-// vim: set et sw=4:
+// vim: set et sw=4 tw=0 sta:
