@@ -23,12 +23,16 @@
  */
 
 #include <config.h>
+#include <config-audiocd.h>
 
 #include <kdemacros.h>
 extern "C"
 {
+	//cdda_interface.h in cdparanoia 10.2 has a member called 'private' which the C++ compiler doesn't like
+	#define private _private   
 	#include <cdda_interface.h>
 	#include <cdda_paranoia.h>
+	#undef private
 	void paranoiaCallback(long, int);
 
 	KDE_EXPORT int kdemain(int argc, char ** argv);
@@ -99,11 +103,10 @@ enum Which_dir {
 
 class AudioCDProtocol::Private {
 public:
-	Private() : cd(KCompactDisc::Asynchronous) {
+	Private() {
 		clearURLargs();
 		s_info = i18n("Information");
 		s_fullCD = i18n("Full CD");
-		discid = 0;
 	}
 
 	void clearURLargs() {
@@ -112,6 +115,28 @@ public:
 		req_track = -1;
 		cddbUserChoice = -1;
 	}
+	
+	bool tocsAreDifferent(struct cdrom_drive *drive)
+	{
+		if (tracks != (uint)drive->tracks) return true;
+		for (int i = 0; i < drive->tracks; ++i)
+		{
+			if (disc_toc[i].dwStartSector != drive->disc_toc[i].dwStartSector || 
+			    disc_toc[i].bFlags != drive->disc_toc[i].bFlags ||
+			    disc_toc[i].bTrack != drive->disc_toc[i].bTrack) return true;
+		}
+		return false;
+	}
+	
+	void setToc(struct cdrom_drive *drive)
+	{
+		for (int i = 0; i < drive->tracks; ++i)
+		{
+			disc_toc[i].dwStartSector = drive->disc_toc[i].dwStartSector;
+			disc_toc[i].bFlags = drive->disc_toc[i].bFlags;
+			disc_toc[i].bTrack = drive->disc_toc[i].bTrack;
+		}
+	}
 
 	// The type/which of request
 	bool req_allTracks;
@@ -130,10 +155,9 @@ public:
 	QString s_fullCD;
 
 	// Current CD
-	unsigned discid;
+	TOC disc_toc[MAXTRK];
 	unsigned tracks;
 	bool trackIsAudio[100];
-	KCompactDisc cd; // keep it around so that we don't assume the disk changed between every stat()
 
 	// CDDB items
 	KCDDB::Result cddbResult;
@@ -191,6 +215,52 @@ AudioCDEncoder *AudioCDProtocol::determineEncoder(const QString & filename)
 	return encoderFromExtension(filename.right(len - pos));
 }
 
+static void setDeviceToCd(KCompactDisc *cd, struct cdrom_drive *drive)
+{
+#if defined(HAVE_CDDA_IOCTL_DEVICE)
+	cd->setDevice(drive->ioctl_device_name, 50, false);
+#elif defined(__FreeBSD__) || defined(__DragonFly__)
+	// FreeBSD's cdparanoia as of january 5th 2006 has rather broken
+	// support for non-SCSI devices. Although it finds ATA cdroms just
+	// fine, there is no straightforward way to discover the device
+	// name associated with the device, which throws the rest of audiocd
+	// for a loop.
+	//
+	if ( !(drive->dev) || (COOKED_IOCTL == drive->interface) )
+	{
+		// For ATAPI devices, we have no real choice. Use the
+		// user selected value, even if there is none.
+		//
+		kWarning(7117) << "Found an ATAPI device, assuming it is the one specified by the user.";
+		cd->setDevice( d->device );
+	}
+	else
+	{
+		kDebug(7117) << "Found a SCSI or ATAPICAM device.";
+		if ( strlen(drive->dev->device_path) > 0 )
+		{
+			cd->setDevice( drive->dev->device_path );
+		}
+		else
+		{
+			// But the device_path can be empty under some
+			// circumstances, so build a representation from
+			// the unit number and SCSI device name.
+			//
+			QString devname = QString::fromLatin1( "/dev/%1%2" )
+				.arg( drive->dev->given_dev_name )
+				.arg( drive->dev->given_unit_number ) ;
+			kDebug(7117) << "  Using derived name " << devname;
+			cd->setDevice( devname );
+		}
+	}
+#else
+#ifdef __GNUC__
+	#warning audiocd ioslave is not going to work for you
+#endif
+#endif
+}
+
 struct cdrom_drive * AudioCDProtocol::initRequest(const KUrl & url)
 {
 	if (url.hasHost())
@@ -210,56 +280,19 @@ struct cdrom_drive * AudioCDProtocol::initRequest(const KUrl & url)
 	if (0 == drive)
 		return 0;
 
-	// Update our knowledge of the disc
-#if defined(HAVE_CDDA_IOCTL_DEVICE)
-	if (d->cd.deviceName() != drive->ioctl_device_name)
-		d->cd.setDevice(drive->ioctl_device_name, 50, false);
-#else
-	// FreeBSD's cdparanoia as of january 5th 2006 has rather broken
-	// support for non-SCSI devices. Although it finds ATA cdroms just
-	// fine, there is no straightforward way to discover the device
-	// name associated with the device, which throws the rest of audiocd
-	// for a loop.
-	//
-	if ( !(drive->dev) || (COOKED_IOCTL == drive->interface) )
+	if (d->tocsAreDifferent(drive))
 	{
-		// For ATAPI devices, we have no real choice. Use the
-		// user selected value, even if there is none.
-		//
-		kWarning(7117) << "Found an ATAPI device, assuming it is the one specified by the user.";
-		d->cd.setDevice( d->device );
-	}
-	else
-	{
-		kDebug(7117) << "Found a SCSI or ATAPICAM device.";
-		if ( strlen(drive->dev->device_path) > 0 )
-		{
-			d->cd.setDevice( drive->dev->device_path );
-		}
-		else
-		{
-			// But the device_path can be empty under some
-			// circumstances, so build a representation from
-			// the unit number and SCSI device name.
-			//
-			QString devname = QString::fromLatin1( "/dev/%1%2" )
-				.arg( drive->dev->given_dev_name )
-				.arg( drive->dev->given_unit_number ) ;
-			kDebug(7117) << "  Using derived name " << devname;
-			d->cd.setDevice( devname );
-		}
-	}
-#endif
-
-
-	if (d->cd.discId() != d->discid && !d->cd.isNoDisc()) {
-		d->discid = d->cd.discId();
-		d->tracks = d->cd.tracks();
-		for(uint i=0; i< d->cd.tracks(); i++)
-			d->trackIsAudio[i] = d->cd.isAudio(i+1);
+		// Update our knowledge of the disc
+		KCompactDisc cd(KCompactDisc::Asynchronous);
+		setDeviceToCd(&cd, drive);
+		d->setToc(drive);
+		
+		d->tracks = cd.tracks();
+		for(uint i=0; i< cd.tracks(); i++)
+			d->trackIsAudio[i] = cd.isAudio(i+1);
 
 		KCDDB::Client c;
-		d->cddbResult = c.lookup(d->cd.discSignature());
+		d->cddbResult = c.lookup(cd.discSignature());
 		if (d->cddbResult == Success)
 		{
 			d->cddbList = c.lookupResponse();
@@ -540,13 +573,15 @@ static void app_dir(UDSEntry& e, const QString & n, size_t s)
 	e.insert( KIO::UDSEntry::UDS_MIME_TYPE, QString("inode/directory"));
 }
 
-static void app_file(UDSEntry& e, const QString & n, size_t s)
+static void app_file(UDSEntry& e, const QString & n, size_t s, const QString &mimetype = QString())
 {
 	e.clear();
 	e.insert( KIO::UDSEntry::UDS_NAME, QFile::decodeName(n.toLocal8Bit()));
 	e.insert( KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
 	e.insert( KIO::UDSEntry::UDS_ACCESS, 0400);
 	e.insert( KIO::UDSEntry::UDS_SIZE, s);
+	if (!mimetype.isEmpty())
+		e.insert( KIO::UDSEntry::UDS_MIME_TYPE, mimetype);
 }
 
 void AudioCDProtocol::listDir(const KUrl & url)
@@ -688,7 +723,7 @@ void AudioCDProtocol::addEntry(const QString& trackTitle, AudioCDEncoder *encode
 		theFileSize = fileSize(firstSector, lastSector, encoder);
 	}
 	UDSEntry entry;
-	app_file(entry, trackTitle + QString(".")+encoder->fileType(), theFileSize);
+	app_file(entry, trackTitle + QString(".")+encoder->fileType(), theFileSize, encoder->mimeType());
 	listEntry(entry, false);
 }
 
@@ -924,7 +959,7 @@ void AudioCDProtocol::parseURLArgs(const KUrl & url)
 
 	QStringList tokens(query.split('&',QString::SkipEmptyParts));
 
-	for (QStringList::ConstIterator it(tokens.begin()); it != tokens.end(); ++it)
+	for (QStringList::ConstIterator it(tokens.constBegin()); it != tokens.constEnd(); ++it)
 	{
 		QString token(*it);
 
